Description Usage Arguments Details Value Author(s) Examples
A function for data whitening.
1 | BSSprep(X)
|
X |
A numeric matrix. Missing values are not allowed. |
A p-variate Y with T observations is whitened, i.e. Y = S^(-1/2)*(X_t - (1/T)*sum_t(X_t)), for t = 1, …, T, where S is the sample covariance matrix of X.
This is often need as a preprocessing step like in almost all blind source separation (BSS) methods. The function is implemented using C++ and returns the whitened data matrix as well as the ingredients to back transform.
A list containing the following components:
Y |
The whitened data matrix. |
X.C |
The mean-centered data matrix. |
COV.sqrt.i |
The inverse square root of the covariance matrix of X. |
MEAN |
Mean vector of X. |
Markus Matilainen, Klaus Nordhausen
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.