Whitening is the first step of almost all blind source separation (BSS) methods. A fast implementation of whitening for BSS is implemented to serve as a lightweight dependency for packages providing BSS methods.
| Package: | BSSprep |
| Type: | Package |
| Version: | 0.1 |
| Date: | 2021-03-25 |
| License: | GPL (>= 2) |
This package contains the single function BSSprep for whitening multivariate data as a preprocessing step for blind source separation (BSS). The package is meant as a fast and lightweight dependency for packages providing BSS methods as whitening is almost always the first step.
Markus Matilainen, Klaus Nordhausen
Maintainer: Markus Matilainen <markus.matilainen@outlook.com>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.